<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Writers Portfolio
 */

function writers_portfolio_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if (is_page()) {
		$get_page_sidebar_settings = get_theme_mod('page_sidebar', 'no');
		$sidebar_layouts = $get_page_sidebar_settings;
		$classes[] = $get_page_sidebar_settings . '-sidebar';
	}elseif (is_single()) {
		$get_post_sidebar_settings = get_theme_mod('post_sidebar', 'no');
		$sidebar_layouts = $get_post_sidebar_settings;
		$classes[] = $get_post_sidebar_settings . '-sidebar';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'writers_portfolio_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function writers_portfolio_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'writers_portfolio_pingback_header' );
if ( ! function_exists( 'writers_portfolio_comment_list' ) ) :
	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 *
	 * @since Shape 1.0
	 */
	function writers_portfolio_comment_list( $comment, $args, $depth ) {
		extract( $args, EXTR_SKIP );
		if ( 'div' == $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'li';
			$add_below = 'div-comment';
		}
		?>
  <<?php echo esc_attr( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
		<?php if ( 'div' == $args['style'] ) : ?>
  <div id="div-comment-<?php comment_ID(); ?>" class="comment-body review-list">
	<?php endif; ?>
	<div class="single-comment">
		<div class="commenter-image">
			<?php
			if ( 0 != $args['avatar_size'] ) {
				echo get_avatar( $comment, $args['avatar_size'] );}
			?>
		</div>
		<div class="commnenter-details">
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'writers-portfolio' ); ?></em>
			<br />
		<?php endif; ?>
			<div class="comment-meta">
				<div class="comment-time">
					<p>
						<time datetime="<?php comment_time( 'c' ); ?>">
							<?php
								echo esc_html( get_comment_date() . ' ' );
								echo esc_html( get_comment_time() );
							?>
						</time>
					</p>
				</div>
				<h4><?php printf( wp_kses_post( '%s', 'writers-portfolio' ), sprintf( '%s', get_comment_author_link() ) ); ?></h4>
			</div>
				<?php comment_text(); ?>
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'depth'     => $depth,
							'max_depth' => $args['max_depth'],
							'before'    => '<div class="reply">',
							'after'     => '</div>',
						)
					)
				);
				?>
		</div>
	</div>
		<?php if ( 'div' == $args['style'] ) : ?>
  </div>
			<?php
  endif;
	}
endif; // ends check for writers_portfolio_comment_list();

/**
 * Writer VCard
 */
function writers_portfolio_author_vcard() {
	?>
	<div class="writer-vcard">
		<div class="writer-vcard__image">
			<?php
			echo get_avatar( get_the_author_meta( 'ID' ), 100, '', '', null );
			?>
		</div>
		<div class="writer-vcard__about">
			<h4><?php echo esc_html( get_the_author_meta( 'nickname' ) ); ?></h4>
			<?php if(!empty(get_the_author_meta( 'description' ))): ?>
			<p><?php echo wp_kses_post( get_the_author_meta( 'description' ) ); ?></p>
			<?php endif; ?>
			<p>
			<?php
			$userpost_count = count_user_posts( get_the_author_meta( 'ID' ), 'post', false );
			if ( $userpost_count > 1 ) {
				$numberingtext = 'posts';
			} else {
				$numberingtext = 'post';
			}
			$userposts = esc_html__( 'The writer has %1$s %2$s', 'writers-portfolio' );
			printf( $userposts, $userpost_count, $numberingtext );
			?>
			 </p>
		</div>
	</div>
	<?php
	return;
}
function writers_portfolio_before_default_page_markup() {
	global $post;
	if (is_home()) {
		$sidebar_layouts = get_theme_mod( 'blog_page_sidebar', 'right' );
	}elseif (is_archive()) {
		$sidebar_layouts = get_theme_mod('archive_page_sidebar', 'right');
	}elseif (is_page()) {
		$get_page_sidebar_settings = get_theme_mod('page_sidebar', 'right');
		$getPageSidebar = get_post_meta( $post->ID, 'writers_portfolio_page-sidebar', true );
		if ('customizer' == $getPageSidebar) {
			$sidebar_layouts = $get_page_sidebar_settings;
		}else{
			$sidebar_layouts = $getPageSidebar;
		}
	}elseif (is_single()) {
		$get_post_sidebar_settings = get_theme_mod('post_sidebar', 'right');
		$getPostSidebar = get_post_meta( $post->ID, 'writers_portfolio_page-sidebar', true );
		if ('customizer' == $getPostSidebar) {
			$sidebar_layouts = $get_page_sidebar_settings;
		}else{
			$sidebar_layouts = $getPostSidebar;
		}
	}elseif (is_search()) {
		$sidebar_layouts = get_theme_mod('search_page_sidebar', 'right');
	}
	$blogcontent    = 'col-md-12';
	if ( $sidebar_layouts === 'right' ) {
		$blogcontent = 'col-md-7 col-lg-8 order-0';
	} elseif ( $sidebar_layouts === 'left' ) {
		$blogcontent = 'col-md-7 col-lg-8 order-1';
	} elseif ( $sidebar_layouts === 'no' ) {
		$blogcontent = 'col-md-12';
	} else {
		$blogcontent = 'col-md-12';
	}
	?>
		<div class="blog-post-section">
			<div class="container">
				<div class="row">
					<div class="<?php echo esc_attr( $blogcontent ); ?>">
	<?php
}
add_action( 'writers_portfolio_before_default_page', 'writers_portfolio_before_default_page_markup' );
function writers_portfolio_after_default_page_markup() {
	global $post;
	if (is_home()) {
		$sidebar_layouts = get_theme_mod( 'blog_page_sidebar', 'right' );
	}elseif (is_archive()) {
		$sidebar_layouts = get_theme_mod('archive_page_sidebar', 'right');
	}elseif (is_page()) {
		$get_page_sidebar_settings = get_theme_mod('page_sidebar', 'right');
		$getPageSidebar = get_post_meta( $post->ID, 'writers_portfolio_page-sidebar', true );
		if ('customizer' == $getPageSidebar) {
			$sidebar_layouts = $get_page_sidebar_settings;
		}else{
			$sidebar_layouts = $getPageSidebar;
		}
	}elseif (is_single()) {
		$get_post_sidebar_settings = get_theme_mod('post_sidebar', 'right');
		$getPostSidebar = get_post_meta( $post->ID, 'writers_portfolio_page-sidebar', true );
		if ('customizer' == $getPostSidebar) {
			$sidebar_layouts = $get_page_sidebar_settings;
		}else{
			$sidebar_layouts = $getPostSidebar;
		}
	}elseif (is_search()) {
		$sidebar_layouts = get_theme_mod('search_page_sidebar', 'right');
	}

	$blogsidebar    = 'col-md-5 col-lg-4 order-1 pl-xl-5 sidebar-sticky';
	$sidebarshow    = true;
	if ( $sidebar_layouts === 'right' ) {
		$blogsidebar = 'col-md-5 col-lg-4 order-1 pl-xl-5 sidebar-sticky';
		$sidebarshow = true;
	} elseif ( $sidebar_layouts === 'left' ) {
		$blogsidebar = 'col-md-5 col-lg-4 order-0 pl-xl-5 sidebar-sticky';
		$sidebarshow = true;
	} elseif ( $sidebar_layouts === 'no' ) {
		$blogsidebar = 'sidebar-hide';
		$sidebarshow = false;
	} else {
		$blogsidebar = 'col-md-5 col-lg-4 order-1 pl-xl-5 sidebar-sticky';
	}
	?>
					 </div>
					<?php if ( $sidebarshow === true ) : ?>
						<div class="<?php echo esc_attr( $blogsidebar ); ?>">
							<?php get_sidebar(); ?>
						</div>
					<?php endif; ?>
				</div>
			</div>
		</div>
		<?php
}
add_action( 'writers_portfolio_after_default_page', 'writers_portfolio_after_default_page_markup' );

/**
 * Get Current Year
 */

 function writers_portfolio_currentYear(){
    return date('Y');
}

/**
 * Get theme Data
 */
function writers_portfolio_author_uri(){
	$themeData = wp_get_theme();
	return $writerURI = $themeData->get( 'WriterURI' );
}

/**
 * Masonry Layout Control
 */
function writers_portfolio_masonry_layout_control(){
	$get_masonry_layout = get_theme_mod('active_masonry_layout', true);
	if (true === $get_masonry_layout) {
		return ' masonry_active';
	}
	return '';
}

/**
 * Limit Excerpt length
 */
function writers_portfolio_post_excerpt_limit( $length ) {
	$length = get_theme_mod('post_loop_excerpt_limit', 42);
   return $length;
}
add_filter( 'excerpt_length', 'writers_portfolio_post_excerpt_limit', 999 );


/**
 * Social Links
 */

function writers_portfolio_social_links(){
	$defaults_links = array(
		[
			'social_icon_class' => 'fa fa-facebook',
			'social_link'  => 'https://facebook.com',
		],
		[
			'social_icon_class' => 'fa fa-twitter',
			'social_link'  => 'https://twitter.com',
		],
		[
			'social_icon_class' => 'fa fa-pinterest',
			'social_link'  => 'https://pinterest.com',
		],
		[
			'social_icon_class' => 'fa fa-instagram',
			'social_link'  => 'https://instagram.com',
		],
		[
			'social_icon_class' => 'fa fa-medium',
			'social_link'  => 'https://medium.com',
		],
	);
	$social_links = get_theme_mod('social_links', $defaults_links);
	foreach( $social_links as $social_link ) :
		?>
		<div class="social-link">
			<a href="<?php echo esc_url($social_link['social_link']);?>" class="<?php echo esc_attr($social_link['social_icon_class']);?>"></a>
		</div>
		<?php
	endforeach;
	wp_reset_query();
}
function writers_portfolio_get_books_layout(){
	$getBooksLayout = get_theme_mod('books_layout', 'product');
	return $getBooksLayout;
}

function writers_portfolio_template_chooser($template){
	  global $wp_query;
	  $post_type = get_query_var('post_type');
	  if( $wp_query->is_search && $post_type == 'books-gallery' )
	  {
	    return locate_template('search-books.php');  //  redirect to archive-search.php
	  }
	  return $template;
}
add_filter('template_include', 'writers_portfolio_template_chooser');

add_action('admin_menu', 'writers_portfolio_personalize');
function writers_portfolio_personalize(){
	remove_submenu_page( 'sb-instagram-feed', 'sb-instagram-feed-about' );
}

add_action('sbi_before_feed', 'writers_portfolio_sbi_before_feed');
function writers_portfolio_sbi_before_feed(){
	?>
	<div class="writers-portfolio-instagram-section">
	<?php
}

add_action('sbi_after_feed', 'writers_portfolio_sbi_after_feed');
function writers_portfolio_sbi_after_feed(){
	?>
	</div>
	<?php
}

function writers_portfolio_utm_url($medium){
    $rawUrl = sprintf(
        'https://rswpthemes.com/author-portfolio-pro-wordpress-theme/?utm_source=free_theme&utm_medium=%s&utm_campaign=writers_portfolio_free',
        rawurlencode($medium)
    );
    return $rawUrl;
}
